//
// tardy - a tar post-processor
// Copyright (C) 2011, 2012 Peter Miller
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

#include <libtardy/rcstring/list.h>


bool
rcstring_list::subset(const rcstring_list &arg)
    const
{
    //
    // test if "(*this) is a subset of (arg)"
    //
    for
    (
        contents_t::const_iterator it = contents.begin();
        it != contents.end();
        ++it
    )
    {
        if (!arg.member(*it))
            return false;
    }
    return true;
}


// vim: set ts=8 sw=4 et :
